@@ -3,7 +3,7 @@
 # Build some of the Autoconf test files.
 
 # Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-# 2009 Free Software Foundation, Inc.
+# 2009, 2010 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -104,9 +104,6 @@ ac_exclude_list='
 	/^AC_FC_SRCEXT$/ {next}
 	/^AC_PATH_((TARGET_)?TOOL|PROG)S?$/ {next}
 
-	# Requires the current language to be Fortran, not C.
-	/^AC_FC_FREEFORM$/ {next}
-
 	# Is a number.
 	/^AC_FD_CC$/ {next}
 
@@ -138,6 +135,9 @@ ac_exclude_list='
 
 	# Already tested by AT_CHECK_MACRO.
 	/^AC_OUTPUT$/ {next}
+
+	# Tested alongside m4_divert_text.
+	/^AC_PRESERVE_HELP_ORDER$/ {next}
 '
 
 
@@ -202,8 +202,8 @@ do
     ## Do not edit by hand.  ##
     ## --------------------- ##
 
-    # Copyright (C) 2000, 2001, 2003, 2004, 2005, 2006, 2007 Free Software
-    # Foundation, Inc.
+    # Copyright (C) 2000, 2001, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+    # 2010 Free Software Foundation, Inc.
 
     AT_BANNER([Testing autoconf/$base macros.])
 
